==> spip_3.0.22.orig.tar.xz: spip/plugins-dist/mediabox/lang/mediabox_it.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/mediabox?lang_cible=it
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'bouton_reinitialiser' => 'Reinizializza',
	'boxstr_close' => 'Chiudi',
	'boxstr_current' => '@current@/@total@',
	'boxstr_next' => 'Prossimo',
	'boxstr_previous' => 'Precedente',
	'boxstr_slideshowStart' => 'Presentazione',
	'boxstr_slideshowStop' => 'Stop',
	'boxstr_zoom' => 'Zoom',

	// E
	'explication_selecteur' => 'Specificare l’elemento target che attiverà il box. (CSS expression o  jQuery)',
	'explication_selecteur_galerie' => 'Specificare l’elemento target da da raggruppare insieme nella galleria. (jQuery o CSS expression)',
	'explication_splash_url' => 'Inserisci l’URL dei media da visualizzare automaticamente in un box alla prima visita del sito pubblico.',
	'explication_traiter_toutes_images' => 'Inserire un box attorno a tutte le immagini?',

	// L
	'label_active' => 'Attivare il mediabox nel sito pubblico',
	'label_apparence' => 'Apparenza',
	'label_aucun_style' => 'Non usare una cornice per impostazione predefinita',
	'label_choix_transition_elastic' => 'Elastico',
	'label_choix_transition_fade' => 'Sfuma',
	'label_choix_transition_none' => 'Senza effetti di transizione',
	'label_maxheight' => 'Altezza massima (% o px)',
	'label_maxwidth' => 'Larghezza massima (% o px)',
	'label_minheight' => 'Altezza minima (% o px)',
	'label_minwidth' => 'Larghezza minima (% o px)',
	'label_opacite' => 'Opacità dello sfondo',
	'label_selecteur_commun' => 'In generale',
	'label_selecteur_galerie' => 'Nella galleria',
	'label_skin' => 'Aspetto grafico',
	'label_slideshow_speed' => 'Tempo di esposizione delle immagini nella presentazione (ms)',
	'label_speed' => 'Velocità di transizione (ms)',
	'label_splash' => 'Splash Box',
	'label_splash_url' => 'URL da mostrare',
	'label_traiter_toutes_images' => 'Immagini',
	'label_transition' => 'Transizione tra due viste',

	// T
	'titre_menu_box' => 'Media Box',
	'titre_page_configurer_box' => 'Configurazione del Media Box'
);

?>

==> spip_3.1.4.orig.tar.xz: spip/plugins-dist/mediabox/lang/mediabox_it.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/mediabox?lang_cible=it
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'bouton_reinitialiser' => 'Reinizializza',
	'boxstr_close' => 'Chiudi',
	'boxstr_current' => '@current@/@total@',
	'boxstr_next' => 'Prossimo',
	'boxstr_previous' => 'Precedente',
	'boxstr_slideshowStart' => 'Presentazione',
	'boxstr_slideshowStop' => 'Stop',
	'boxstr_zoom' => 'Zoom',

	// E
	'explication_selecteur' => 'Specificare l’elemento target che attiverà il box. (CSS expression o  jQuery)',
	'explication_selecteur_galerie' => 'Specificare l’elemento target da da raggruppare insieme nella galleria. (jQuery o CSS expression)',
	'explication_splash_url' => 'Inserisci l’URL dei media da visualizzare automaticamente in un box alla prima visita del sito pubblico.',
	'explication_traiter_toutes_images' => 'Inserire un box attorno a tutte le immagini?',

	// L
	'label_active' => 'Attivare il mediabox nel sito pubblico',
	'label_apparence' => 'Apparenza',
	'label_aucun_style' => 'Non usare una cornice per impostazione predefinita',
	'label_choix_transition_elastic' => 'Elastico',
	'label_choix_transition_fade' => 'Sfuma',
	'label_choix_transition_none' => 'Senza effetti di transizione',
	'label_maxheight' => 'Altezza massima (% o px)',
	'label_maxwidth' => 'Larghezza massima (% o px)',
	'label_minheight' => 'Altezza minima (% o px)',
	'label_minwidth' => 'Larghezza minima (% o px)',
	'label_opacite' => 'Opacità dello sfondo',
	'label_selecteur_commun' => 'In generale',
	'label_selecteur_galerie' => 'Nella galleria',
	'label_skin' => 'Aspetto grafico',
	'label_slideshow_speed' => 'Tempo di esposizione delle immagini nella presentazione (ms)',
	'label_speed' => 'Velocità di transizione (ms)',
	'label_splash' => 'Splash Box',
	'label_splash_height' => 'Altezza (% o px)',
	'label_splash_url' => 'URL da mostrare',
	'label_splash_width' => 'Larghezza (% o px)',
	'label_traiter_toutes_images' => 'Immagini',
	'label_transition' => 'Transizione tra due viste',

	// T
	'titre_menu_box' => 'Media Box',
	'titre_page_configurer_box' => 'Configurazione del Media Box'
);

?>
